# Model - 3rd phase of Tai-Chi Engine
> The model is assembled in a pincer design, you've already set your Xs, and you've set your Y. We try to figure out how to design the model for the task.
* Xs quantify =decide=> Entry Model Map
* Exit Model <=decide= Y quantify
* YourAwesomeModel = Assemble(Entry Model Map, Exit Model)

> 靜如山岳 動若江河

## For developers
The model parts, for now, has to be either an entry model or a exit model.

* You have to create a class function called ```from_quantify```, we can configure the model detail from quantify class.